notes

package
v0.0.0-...-1b1f046 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 5, 2025 License: MIT Imports: 11 Imported by: 0

Documentation

Overview

Implements functions pertaining to loading, sorting, filtering, and tagging notes.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Consolidate

func Consolidate(notebooks []map[string]note.Note) map[string]note.Note

Applies notes "overrides", resolving title conflicts that exist among notebooks by preferring more local notes over less local notes

func Filter

func Filter(notebooks []map[string]note.Note, tags []string) []map[string]note.Note

Filter filters notes that do not match `tag(s)`

func Load

func Load(notebooks []notebook.Notebook) ([]map[string]note.Note, error)

Produces a map of note names to filesystem paths

func Sort

func Sort(notes map[string]note.Note) []note.Note

Organizes the notes into an alphabetically-sorted slice

func Tags

func Tags(notebooks []map[string]note.Note) []string

Returns a slice of all tags in use in any note

Types

This section is empty.

Jump to