Documentation
¶
Overview ¶
Implements functions pertaining to loading, sorting, filtering, and tagging notes.
Index ¶
- func Consolidate(notebooks []map[string]note.Note) map[string]note.Note
- func Filter(notebooks []map[string]note.Note, tags []string) []map[string]note.Note
- func Load(notebooks []notebook.Notebook) ([]map[string]note.Note, error)
- func Sort(notes map[string]note.Note) []note.Note
- func Tags(notebooks []map[string]note.Note) []string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Consolidate ¶
Applies notes "overrides", resolving title conflicts that exist among notebooks by preferring more local notes over less local notes
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.